JWalk: Representational learning on graphs
==========================================

.. image:: images/jwalk_logo.gif

.. toctree::
   :maxdepth: 2

   overview
   changelog

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`